@@ -5,7 +5,7 @@ use warnings;
 
 use WiringPi::API qw(:wiringPi);
 
-our $VERSION = '2.36.4';
+our $VERSION = '2.36.5';
 
 sub new {
     my ($class, $channel, $speed) = @_;
@@ -15,6 +15,13 @@ sub new {
     $self->_channel($channel);
     $self->_channel($speed);
 
+    # check if we're in bit-banging mode
+
+    if ($self->_cs){
+        pin_mode($self->_cs, 1);
+        write_pin($self->_cs, 1);
+    }
+
     if (wiringPiSPISetup($self->_channel, $self->_speed) < 0){
         die "couldn't establish communication on the SPI bus\n";
     }
@@ -23,19 +30,45 @@ sub new {
 }
 sub rw {
     my ($self, $buf, $len) = @_;
-    my @read_buf = spiDataRW($self->_channel, $buf, $len);
-    return @read_buf;
+
+    if ($self->_cs){
+        pin_mode($self->_cs, 0);
+        @$buf = spiDataRW($self->_channel, $buf, $len);
+        pin_mode($self->_cs, 1);
+    }
+    else {
+        @$buf = spiDataRW($self->_channel, $buf, $len);
+    }
+
+    return @$buf;
 }
 sub _channel {
     my ($self, $chan) = @_;
-    $self->{channel} = $chan if defined $chan;
+
+    if (defined $chan){
+        if ($chan > 1){
+            $self->_cs($chan);
+            $self->{channel} = 0;
+        }
+        else {
+            $self->{channel} = $chan;
+        }
+    }
+
     return $self->{channel};
 }
+sub _cs {
+    my ($self, $cs) = @_;
+
+    $self->{cs} = $cs if defined $cs;
+    return $self->{cs};
+}
 sub _speed {
     my ($self, $speed) = @_;
     $self->{speed} = $speed if defined $speed;
     return $self->{speed} || 1000000;
 }
+sub _vim{};
 
 1;
 __END__
@@ -47,25 +80,22 @@ bus on Raspberry Pi
 
 =head1 SYNOPSIS
 
-    my $channel = 0;
+    # channel 0 and 1 are the hardware SPI pins
+    # CE0 and CE1
 
-    my $spi = RPi::SPI->new($channel);
+    my $spi = RPi::SPI->new(0);
 
     my $buf = [0x01, 0x02];
     my $len = 2;
 
-    my @read_buf = $spi->rw($buf, $len);
+    @$buf = $spi->rw($buf, $len);
 
-    # write occurs, then a read, and the read buffer overwrites the
-    # write TX buffer, and we return an array of that data
+    # use a GPIO pin to expand the number of SPI
+    # channels. We'll bit-bang automatically. The
+    # GPIO pin must connect to the CS/SS pin on the
+    # IC you're using
 
-    print "$_\n" for @read_buf;
-
-    # read-only
-
-    $buf = [0, 0, 0]; # three dummy bytes to signify a read of three bytes
-
-    my @read_bytes = $spi->rw($buf, 2);
+    $spi = RPi::SPI->new(26); # GPIO 26 is the CS
 
 =head1 DESCRIPTION
 
@@ -74,6 +104,10 @@ to the channels on the Serial Peripheral Interface (SPI) bus. Although it was
 designed for the Raspberry Pi, that's not a hard requirement, and it should work
 on any Unix-type system that has support for SPI.
 
+You can use the hardware SPI pins CE0 and CE1 on the Raspberry Pi, but if you
+need more SPI slaves, we'll also automatically bit-bang the SPI bus using
+a standard GPIO pin for the Slave Select instead.
+
 =head1 METHODS
 
 =head2 new
@@ -88,6 +122,9 @@ Parameters:
 The SPI bus channel to initialize.
 
 Mandatory: Integer, C<0> for C</dev/spidev0.0> or C<1> for C</dev/spidev0.1>.
+You can also send in any number above C<1>. If so, we'll treat it as a GPIO
+pin (connected to the CS/SS pin of the IC), and we'll bit-bang the CS
+automatically as to free up the onboard hardware channels.
 
     $speed
 
@@ -115,7 +152,7 @@ Mandatory: Integer, the number of array elements in the C<$buf> parameter sent
 in above.
 
 Return: The write buffer, after being re-populated with the read data, as a Perl
-array.
+array reference.
 
 Dies if we can't open the SPI bus.
 
